@@ -402,6 +402,9 @@ int parse(char *from, int pos, char *delim, char *to, int to_length, int fixed)
 	}
         if(k >= to_length) {
 		/* insufficient buffer space */
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_WARNING, "parse->destination buffer too small! E-mail equ@equnet.org for a fix\n");
+#endif
                 return -1;
         }
         to[k] = '\0';
