@@ -204,7 +204,7 @@ int main(int argc, char *argv[])
 	mystate->loopforever = 1;
 	while(mystate->loopforever) {
 #ifdef DEBUG
-        oer_debug(OER_DEBUG_FLOOD, "main->mainloop\n");
+		oer_debug(OER_DEBUG_FLOOD, "main->mainloop\n");
 #endif
 		FD_ZERO(&rsock);
 		FD_SET(mystate->sockfd, &rsock);
@@ -234,7 +234,6 @@ int main(int argc, char *argv[])
 					break;
 				}
 			}
-			continue;
 		}
 		reconnect();
 		/* retval == 0, timeout */
@@ -253,7 +252,7 @@ int main(int argc, char *argv[])
 		/* do some housekeeping */
 		processenv();	
 		/* check if it's safe to do some server actions */
-		if((mystate->last_actions + 1) >= mystate->now) {
+		if(mystate->now <= mystate->last_actions) {
 			continue;
 		}
 		switch(processtimeds()) {
