@@ -60,7 +60,7 @@ void parseirc(char *serveroutput)
 	char nick[NICKLEN + 1];
 	char nick2[NICKLEN + 1];
 	char temp_nick[STRINGLEN + 1];
-	char target[NICKLEN + 1];
+	char target[STRINGLEN + 1];
 	char m;
 	char *restptr;
 	char *ptr;
@@ -677,7 +677,7 @@ void parseirc(char *serveroutput)
 			return;
 		}
 		restpos = 0;
-		if((restpos = parse(restptr, restpos, " ", target, NICKLEN, 0)) < 0) {
+		if((restpos = parse(restptr, restpos, " ", target, STRINGLEN, 0)) < 0) {
 			return;
 		}
 		if(isme(target)) {
@@ -760,7 +760,7 @@ void parseirc(char *serveroutput)
 		bans = 0;
 		deops = 0;
 		while(1) {
-			nrestpos = parse(restptr, restpos, " ", target, NICKLEN, 0);
+			nrestpos = parse(restptr, restpos, " ", target, STRINGLEN, 0);
 			if(nrestpos == restpos || nrestpos < 0) {
 				break;
 			}
@@ -1397,7 +1397,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "random kick by %s\n", nick);
-		kickuser(this, u->nick, outstring);
+		kickuser(this, mystate->now, u->nick, outstring);
 		return;
 	case OER_WHICHCOMMAND_RANDOM_BANKICK:
 #ifdef DEBUG
@@ -1418,8 +1418,8 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "random ban kick by %s\n", nick);
-		banuser(this, u->nick);
-		kickuser(this, u->nick, outstring);
+		banuser(this, mystate->now - 1, u->nick);
+		kickuser(this, mystate->now, u->nick, outstring);
 		return;
 	case OER_WHICHCOMMAND_SYNC:
 #ifdef DEBUG
@@ -1506,9 +1506,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                 }
 		if(!strlen(restptr)) {
 			/* the messager wants to be opped */
-			if(!isopnow(this, nick) && (haschanflags(this, "u") && isallowedop(this, nick))) {
-				mmode_new(this, mystate->now, "+o", nick);
+			if(isopnow(this, nick)) {
+				return;
 			}
+			if(haschanflags(this, "u") && !isallowedop(this, nick)) {
+				return;
+			}
+			mmode_new(this, mystate->now, "+o", nick);
 			return;
 		}
 		/* op all given nicks */
@@ -1519,9 +1523,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(!isopnow(this, p1) && (haschanflags(this, "u") && isallowedop(this, p1))) {
-				mmode_new(this, mystate->now, "+o", p1);
+			if(isopnow(this, p1)) {
+				continue;
 			}
+			if(haschanflags(this, "u") && !isallowedop(this, p1)) {
+				continue;
+			}
+			mmode_new(this, mystate->now, "+o", p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_DOP:
@@ -1542,9 +1550,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
                 }
 		if(!strlen(restptr)) {
 			/* the messager wants to be de-opped */
-			if(isopnow(this, nick) && !(haschanflags(this, "D") && isallowedop(this, nick))) {
-				mmode_new(this, mystate->now, "-o", nick);
+			if(!isopnow(this, nick)) {
+				return;
 			}
+			if(haschanflags(this, "D") && isallowedop(this, nick)) {
+				return;
+			}
+			mmode_new(this, mystate->now, "-o", nick);
 			return;
 		}
 		/* de-op all given nicks */
@@ -1555,9 +1567,13 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			if(isopnow(this, p1) && !(haschanflags(this, "D") && isallowedop(this, p1))) {
-				mmode_new(this, mystate->now, "-o", p1);
+			if(!isopnow(this, p1)) {
+				continue;
 			}
+			if(haschanflags(this, "D") && isallowedop(this, p1)) {
+				continue;
+			}
+			mmode_new(this, mystate->now, "-o", p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_VOICE:
@@ -1659,7 +1675,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			banuser(this, p1);
+			banuser(this, mystate->now, p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_UNBAN:
@@ -1689,7 +1705,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 				break;
 			}
 			ppos = nppos;
-			unbanuser(this, p1);
+			unbanuser(this, mystate->now, p1);
 		}
 		return;
 	case OER_WHICHCOMMAND_BANKICK:
@@ -1715,8 +1731,8 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		banuser(this, p1);
-		kickuser(this, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
+		banuser(this, mystate->now - 1, p1);
+		kickuser(this, mystate->now, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_KICK:
 #ifdef DEBUG
@@ -1741,7 +1757,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if((ppos = parse(restptr, ppos, " ", p1, STRINGLEN, 0)) < 0) {
 			return;
 		}
-		kickuser(this, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
+		kickuser(this, mystate->now, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_INVITE:
 #ifdef DEBUG
